summaryrefslogtreecommitdiff
path: root/src/thumbnail.h
diff options
context:
space:
mode:
authorDaniel Friesel <derf@derf.homelinux.org>2010-05-31 00:38:45 +0200
committerDaniel Friesel <derf@derf.homelinux.org>2010-05-31 00:38:45 +0200
commit62ad1f1e5c7164eab0e19af65f6384a13ad701ee (patch)
tree8e7542e463486e8604aa89637bae362d09d9102f /src/thumbnail.h
parentcf36be979939c93315b77f24575dc4028916776d (diff)
Support caching of thumbnails up to 256x256 pixels (.thumbnails/large)
Depending on --thumb-width/--thumb-height, either .thumbnails/normal or .thumbnails/large is used. For higher dimensions, thumbnail caching is still silently disabled, this should also be what the standard indicates.
Diffstat (limited to 'src/thumbnail.h')
-rw-r--r--src/thumbnail.h24
1 files changed, 14 insertions, 10 deletions
diff --git a/src/thumbnail.h b/src/thumbnail.h
index d015994..a384d11 100644
--- a/src/thumbnail.h
+++ b/src/thumbnail.h
@@ -45,20 +45,24 @@ typedef struct thumbnail {
typedef struct thumbmode_data {
/* FIXME: text_area_h not really needed, remove? */
- Imlib_Image im_main; /* base image which all thumbnails are rendered on */
- Imlib_Image im_bg; /* background for the thumbnails */
+ Imlib_Image im_main; /* base image which all thumbnails are rendered on */
+ Imlib_Image im_bg; /* background for the thumbnails */
- Imlib_Font font_main; /* font used for file info */
- Imlib_Font font_title; /* font used for title */
+ Imlib_Font font_main; /* font used for file info */
+ Imlib_Font font_title; /* font used for title */
- int w, h, bg_w, bg_h; /* dimensions of the window and bg image */
+ int w, h, bg_w, bg_h; /* dimensions of the window and bg image */
- int thumb_tot_h; /* total space needed for a thumbnail including description */
- int text_area_w, text_area_h; /* space needed for thumbnail description */
+ int thumb_tot_h; /* total space needed for a thumbnail including description */
+ int text_area_w, text_area_h; /* space needed for thumbnail description */
+
+ int max_column_w; /* FIXME: description */
+ int vertical; /* FIXME: vertical in what way? */
+
+ int cache_thumbnails; /* use cached thumbnails from ~/.thumbnails */
+ int cache_dim; /* 128 = 128x128 ("normal"), 256 = 256x256 ("large") */
+ char *cache_dir; /* "normal"/"large" (.thumbnails/...) */
- int max_column_w; /* FIXME: description */
- int vertical; /* FIXME: vertical in what way? */
- int cache_thumbnails; /* use cached thumbnails from ~/.thumbnails/normal */
} thumbmode_data;
feh_thumbnail *feh_thumbnail_new(feh_file * fil, int x, int y, int w, int h);